#
# spec file for package domination
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           domination
Version:        1.2.7
Release:        bp155.1.4
Summary:        Board game that is a bit like the well known game Risk
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Turn Based
URL:            http://domination.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/Domination/%{version}/Domination_%{version}.zip
Source1:        %{name}-FlashGUI.sh
Source2:        %{name}-Increment1GUI.sh
Source3:        %{name}-SimpleGUI.sh
Source4:        %{name}-SwingGUI.sh
Source5:        %{name}.desktop
Source6:        %{name}.png
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       %{name}-data
Requires:       jre >= 1.6.0
BuildArch:      noarch

%description
Domination is a board game that is a bit like the well known game Risk.

Domination is a game that is a bit like the well known board game of Risk
or RisiKo. It has many game options and includes many maps.

Written in java it includes a map editor, a simple map format, multiplayer
network play, single player, hotseat, 5 user interfaces and many more features,
it works in all OSs that run java.

%prep
%setup -q -n Domination

# Convert to unix line end
find -name "*.txt" -print0 -or -name "*.ini" -print0 -or -name "*.cmd" -print0 \
    -or -name "*.htm" -print0 -or -name "*.cards" -print0 -or -name "*.map" -print0 \
    -or -name "*.properties" -print0 | xargs -0 dos2unix

%build

%install
# install wrappers
install -Dm 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}-FlashGUI
install -Dm 0755 %{SOURCE2} %{buildroot}%{_bindir}/%{name}-Increment1GUI
install -Dm 0755 %{SOURCE3} %{buildroot}%{_bindir}/%{name}-SimpleGUI
install -Dm 0755 %{SOURCE4} %{buildroot}%{_bindir}/%{name}-SwingGUI

# install directories
mkdir -p %{buildroot}%{_datadir}/%{name}/{help,lib,maps,maps/preview,resources}
for d in help lib resources ; do
   install -Dm 0644 $d/* %{buildroot}%{_datadir}/%{name}/$d
done

cp -a maps %{buildroot}%{_datadir}/%{name}/

# install files
for f in *.jar *.txt *.ini ; do
    install -Dm 0644 "$f" %{buildroot}%{_datadir}/%{name}
done
# install icon
install -Dm 0644 %{SOURCE6} %{buildroot}%{_datadir}/pixmaps/%{name}.png
# install Desktop file
install -Dm 0644 %{SOURCE5} %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}

%files
%{_bindir}/%{name}-*GUI
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}

%changelog
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.7:
  * Fix for online games over 1MB not loading
  * Much faster startup time (6 seconds faster on mac)
  * MapEditor: Fill Shapes right click option added to allow filling holes in countries
  * SwingGUI: fix for online lobby sometimes not repainting when tabs switched
  * Lobby: when player resigns, the player is converted to easy AI instead of crap AI
  * New field in game engine for maxCardsPerPlayer
  * Fix grasshopper error on java 1.8 on mac when appending to log from interrupted thread
  * Show connection errors in Lobby
  * Fix error in replay when user has made invalid commands (e.g. tried to place 10 armies when they only have 9)
  * SwingUI on macOS use native file chooser for selecting files (fix for Documents folder not showing files)
  * Game engine supports over 9 players if configured with "game.players.max" in game.ini
  * SwingGUI: can select 3 defending dice in any game mode
  * Fix for lobby failed to launch when javax.crypto.JceSecurity not found
  * New field in game for minimumNewArmies that can be set depending on the game options
  * New Italian rules: no minimum armies, if you have less than 3 counties, you get 0 armies
  * New Italian rules: during trade get 2 extra armies for each country, and can place them anywhere
  * New Italian rules: game engine/network play version now 14
* Fri Dec  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.2.4
  * Better 'Troop Strength' view
  * New right-click options on countries list in the MapEditor
  * Various other bug fixes.
* Sun Apr 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.2.3:
  * PlayerList for Lobby games shows players with correct color
  * Fix for hi-res Linux jdk-11 that sometimes uses display density
    instead of scale
  * Now works for gtk dark theme
  * Auto-Defend now happens on the server for Lobby Multiplayer
  * Map Editor shows rectangle for country that is used on cards
  * SwingGUI: Options and AI speed setting put into same Options
    Dialog
  * max players can be changed in game.ini config file
  * MapEditor: fixed zoom to keep the mouse position on map static
  * SwingGUI: testing tab, show player for online games
  * Can create private games online with a password to enter
  * Can view cards and missions even when it is not your turn
  * Filter online game maps by Michiel Pater
  * Do not show dice statistics for turns when the player rolled no dice
  * French text update by Adrien Laugueux
  * Can Flag 🚩 a game as inappropriate with right click menu option
  * MapEditor: checks for overlapping circles
  * MapEditor: warning on no cards in map
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.2.1. Check the installed ChangeLog.txt file for the
  complete list of changes.
  * Improved hi-res support
  * Updated translations
  * Map editor fixes.
- Spec cleanup.
- Fix the package group.
* Tue Sep 22 2015 nemysis@openSUSE.org
- Update to 1.1.1.6, please look
  /usr/share/domination/ChangeLog.txt
* Mon Mar 30 2015 dimstar@opensuse.org
- Add domination.png as icon (converted from resources/icon.ico):
  The .ico file at least is 32x32 pixels, whereas the provided pnt
  was only 16x16.
* Fri Nov 14 2014 nemysis@gmx.ch
- Change Source0 Web URL
* Thu Nov 13 2014 nemysis@gmx.ch
- Use Group Amusements/Games/Arcade/Strategy instead of
  Amusements/Games/Arcade/StrategyGame
- Use check for openSUSE %%if 0%%{?suse_version}
- Remove BuildRequires for desktop-file-utils
- Fix typo
* Sun Oct  5 2014 nemysis@gmx.ch
- Change %%fdupes
* Tue Sep 30 2014 nemysis@gmx.ch
- Remove not needed mkdir -p
- Use %%{name}.desktop instead of Desktop Entry in spec
* Wed Sep 17 2014 nemysis@gmx.ch
- Initial package creation
